import asyncio
import logging
from pathlib import Path
import random
import re
from datetime import datetime

from clockblocker_bot.config import config
from clockblocker_bot.utils.constants import CLOCKBLOCKER_ID, S3RIUS_ID
from clockblocker_bot.utils.rotate_words import rotate_words
from clockblocker_bot.utils.decorators import (
    beware_the_croud_policy,
    clean_up_policy,
    ignore_with_id,
    mark_unread,
)
from telethon import events

logger = logging.getLogger(__name__)


@config.telegram_client.on(events.NewMessage(pattern="^.h$"))
@mark_unread
@beware_the_croud_policy
@clean_up_policy
async def show_help(event: events.NewMessage.Event):
    help_text = Path(__file__).parent / "static_messages" / "help.txt"
    print('h')
    with open(help_text) as f:
        contents = f.read()
    return await event.respond(contents)


@config.telegram_client.on(
    events.NewMessage(pattern=r"\W*[пП]+\s*[рР]+\s*[иИ]+\s*[вВ]+\s*[Ее]+\s*[тТ]+\W*")
)
@ignore_with_id(CLOCKBLOCKER_ID)
@beware_the_croud_policy
@mark_unread
@clean_up_policy
async def ci(event: events.NewMessage.Event):
    return await event.respond("Как дела?")


@config.telegram_client.on(
    events.NewMessage(
        pattern=re.compile(r".*(Блядь|БлsDь|лябдь|,zklm|блядь|Блядь|бляьд|Бляьд).*", flags=re.DOTALL | re.MULTILINE),
        outgoing=True,
    )
)
@mark_unread
async def blyad(event: events.NewMessage.Event):
    blyads = ["Блядь", "БлsDь", "лябдь", ",zklm", "блядь", "Блядь", "бляьд", "Бляьд"]
    start_time = datetime.now()
    current_time = start_time
    s = event.message.message
    print('blyad')
    
    while (current_time - start_time).seconds < 10:
        s = rotate_words(s, blyads)
        print('message: ',  event.message.message, s)
        await event.message.edit(s)
        await asyncio.sleep(1)
        current_time = datetime.now()


@config.telegram_client.on(events.NewMessage(pattern=r".*сломал(ось|ись|ась|ся).*"))
@beware_the_croud_policy
@mark_unread
@clean_up_policy
async def reboot_advice(event: events.NewMessage.Event):
    return await event.respond("Стоит попробовать выключить и включить")


@config.telegram_client.on(events.NewMessage(pattern=r"[\)\s]+"))
@ignore_with_id(S3RIUS_ID, CLOCKBLOCKER_ID)
@clean_up_policy
@mark_unread
async def smile_back(event: events.NewMessage.Event):
    return await event.respond(event.message.message)
