import asyncio
import functools
import logging
from typing import Union

from clockblocker_bot.utils.constants import CLOCKBLOCKER_ID, S3RIUS_ID
from telethon import events, functions, types

logger = logging.getLogger(__name__)

chat_union = Union[types.User, types.Chat, types.Channel]

def ignore_with_id(*ids):
    def ignore_inner(f):
        @functools.wraps(f)
        async def wrapper(event: events.NewMessage.Event):
            try:
                if not event.message.from_id.user_id in ids:
                    await f(event)

            except Exception as e:
                logger.error(f"Exception found: {e}")

        return wrapper
    return ignore_inner

def only_clockblocker(f):
    @functools.wraps(f)
    async def wrapper(event: events.NewMessage.Event):
        try:
            if event.message.from_id == CLOCKBLOCKER_ID:
                await f(event)

        except Exception as e:
            logger.error(f"Exception found: {e}")

    return wrapper


def mark_unread(f):
    @functools.wraps(f)
    async def wrapper(event: events.NewMessage.Event):
        try:
            await f(event)
        except Exception as e:
            logger.error(f"Exception found: {e}")
        chat = await event.get_chat()
        functions.messages.MarkDialogUnreadRequest(chat, unread=True)

    return wrapper


def clean_up_policy(f):
    @functools.wraps(f)
    async def wrapper(event: events.NewMessage.Event):
        try:
            reply_msg: types.Message = await f(event)
            await asyncio.sleep(5)
            await reply_msg.delete()
        except Exception as e:
            logger.error(f"Exception found: {e}")

    return wrapper


def beware_the_croud_policy(f):
    @functools.wraps(f)
    async def wrapper(event: events.NewMessage.Event):
        try:
            chat: chat_union = await event.get_chat()
            ok = isinstance(chat, types.User)
            if isinstance(chat, types.Chat) or isinstance(chat, types.Channel):
                ok = chat.participants_count < 20
            if ok:
                await f(event)

        except Exception as e:
            logger.error(f"Exception found: {e}")

    return wrapper
